use flax::{component, BoxedSystem, EntityBorrow, Query, System};
use winit::window::Window;

component! {
    pub window_width: f32,
    pub window: Window,
    pub counter: i32,

    pub resources,
}

pub fn update_distance_system() -> BoxedSystem {
    System::builder()
        .with_name("update_distance")
        .with_query(
            Query::new((window_width().as_mut(), window(), counter().as_mut())).entity(resources()),
        )
        .build(|mut query: EntityBorrow<_>| {
            if let Ok((window_width, _window, counter)) = query.get() {
                // println!("Win width: {window_width}");
                *(window_width as &mut f32) = *(counter as &mut i32) as f32;
                *(counter as &mut i32) += 1;
            }
        })
        .boxed()
}

pub fn log_window_system() -> BoxedSystem {
    let query = Query::new((window_width(), window())).entity(resources());

    System::builder()
        .with_query(query)
        .build(|mut q: EntityBorrow<_>| {
            if let Ok((width, wind)) = q.get() {
                println!("window id: {:?}", (wind as &Window).id());
                println!("Config changed width: {width}");
            } else {
                println!("No config change");
            }
        })
        .boxed()
}
