use std::{fs, path::Path};

use flax::{BoxedSystem, CommandBuffer, EntityBorrow, Query, System};
use serde_lexpr::from_str;

use super::{components::{config, notify_file_event, resources}, Config};

pub fn read_config_system() -> BoxedSystem {
    let query = Query::new(notify_file_event()).entity(resources());
    System::builder()
        .with_name("read_config")
        .with_cmd_mut()
        .with_query(query)
        .build(|cmd: &mut CommandBuffer, mut q: EntityBorrow<_>| {
            if let Ok(n_event) = q.get() {
                if (n_event as &notify::Event).kind.is_modify() {
                    println!("file modified: {:?}", (n_event as &notify::Event).paths);
                    cmd.set(resources(), config(), read_engine_config());
                }
            }
        })
        .boxed()
}

fn read_engine_config() -> Config {
    let config_path = Path::new("engine_config.scm");

    let config_file = fs::read_to_string(config_path).unwrap();
    let config: Config = from_str::<Config>(&config_file).expect("Failed to parse config file");

    config
}

pub fn read_notify_events_system() -> BoxedSystem {
    let query = Query::new(config().as_mut()).entity(resources());
    System::builder()
        .with_name("first_read_config")
        .with_cmd_mut()
        .with_query(query)
        .build(|cmd: &mut CommandBuffer, mut q: EntityBorrow<_>| {
            if let Ok(_config) = q.get() {
                return;
            } else {
                println!("read_notify_events_system: config read");
                cmd.set(resources(), config(), read_engine_config());
            }

            std::thread::sleep(std::time::Duration::from_secs(3));
        })
        .boxed()
}
